bayespy.inference.vmp.nodes.gaussian.GaussianToGaussianGammaISO.has_plotter
===========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianToGaussianGammaISO.has_plotter